@@ -482,6 +482,14 @@ pub enum Statement {
         file_format: Option<FileFormat>,
         location: Option<String>,
         query: Option<Box<Query>>,
+        without_rowid: bool,
+    },
+    /// SQLite's `CREATE VIRTUAL TABLE .. USING <module_name> (<module_args>)`
+    CreateVirtualTable {
+        name: ObjectName,
+        if_not_exists: bool,
+        module_name: Ident,
+        module_args: Vec<Ident>,
     },
     /// CREATE INDEX
     CreateIndex {
@@ -647,6 +655,7 @@ impl fmt::Display for Statement {
                 file_format,
                 location,
                 query,
+                without_rowid,
             } => {
                 // We want to allow the following options
                 // Empty column list, allowed by PostgreSQL:
@@ -672,6 +681,10 @@ impl fmt::Display for Statement {
                     // PostgreSQL allows `CREATE TABLE t ();`, but requires empty parens
                     write!(f, " ()")?;
                 }
+                // Only for SQLite
+                if *without_rowid {
+                    write!(f, " WITHOUT ROWID")?;
+                }
 
                 if *external {
                     write!(
@@ -689,6 +702,24 @@ impl fmt::Display for Statement {
                 }
                 Ok(())
             }
+            Statement::CreateVirtualTable {
+                name,
+                if_not_exists,
+                module_name,
+                module_args,
+            } => {
+                write!(
+                    f,
+                    "CREATE VIRTUAL TABLE {if_not_exists}{name} USING {module_name}",
+                    if_not_exists = if *if_not_exists { "IF NOT EXISTS " } else { "" },
+                    name = name,
+                    module_name = module_name
+                )?;
+                if !module_args.is_empty() {
+                    write!(f, " ({})", display_comma_separated(module_args))?;
+                }
+                Ok(())
+            }
             Statement::CreateIndex {
                 name,
                 table_name,
