@@ -351,6 +351,7 @@ define_keywords!(
     ROLLBACK,
     ROLLUP,
     ROW,
+    ROWID,
     ROWS,
     ROW_NUMBER,
     SAVEPOINT,
@@ -437,6 +438,7 @@ define_keywords!(
     VAR_SAMP,
     VERSIONING,
     VIEW,
+    VIRTUAL,
     WHEN,
     WHENEVER,
     WHERE,
