@@ -55,6 +55,7 @@ pub enum IsLateral {
     Lateral,
     NotLateral,
 }
+use crate::ast::Statement::CreateVirtualTable;
 use IsLateral::*;
 
 impl From<TokenizerError> for ParserError {
@@ -986,16 +987,35 @@ impl Parser {
             self.parse_create_view()
         } else if self.parse_keyword(Keyword::EXTERNAL) {
             self.parse_create_external_table()
+        } else if self.parse_keyword(Keyword::VIRTUAL) {
+            self.parse_create_virtual_table()
         } else if self.parse_keyword(Keyword::SCHEMA) {
             self.parse_create_schema()
         } else {
-            self.expected(
-                "TABLE, VIEW, INDEX or SCHEMA after CREATE",
-                self.peek_token(),
-            )
+            self.expected("an object type after CREATE", self.peek_token())
         }
     }
 
+    /// SQLite-specific `CREATE VIRTUAL TABLE`
+    pub fn parse_create_virtual_table(&mut self) -> Result<Statement, ParserError> {
+        self.expect_keyword(Keyword::TABLE)?;
+        let if_not_exists = self.parse_keywords(&[Keyword::IF, Keyword::NOT, Keyword::EXISTS]);
+        let table_name = self.parse_object_name()?;
+        self.expect_keyword(Keyword::USING)?;
+        let module_name = self.parse_identifier()?;
+        // SQLite docs note that module "arguments syntax is sufficiently
+        // general that the arguments can be made to appear as column
+        // definitions in a traditional CREATE TABLE statement", but
+        // we don't implement that.
+        let module_args = self.parse_parenthesized_column_list(Optional)?;
+        Ok(CreateVirtualTable {
+            name: table_name,
+            if_not_exists,
+            module_name,
+            module_args,
+        })
+    }
+
     pub fn parse_create_schema(&mut self) -> Result<Statement, ParserError> {
         let schema_name = self.parse_object_name()?;
         Ok(Statement::CreateSchema { schema_name })
@@ -1021,6 +1041,7 @@ impl Parser {
             file_format: Some(file_format),
             location: Some(location),
             query: None,
+            without_rowid: false,
         })
     }
 
@@ -1110,6 +1131,9 @@ impl Parser {
         // parse optional column list (schema)
         let (columns, constraints) = self.parse_columns()?;
 
+        // SQLite supports `WITHOUT ROWID` at the end of `CREATE TABLE`
+        let without_rowid = self.parse_keywords(&[Keyword::WITHOUT, Keyword::ROWID]);
+
         // PostgreSQL supports `WITH ( options )`, before `AS`
         let with_options = self.parse_with_options()?;
 
@@ -1130,6 +1154,7 @@ impl Parser {
             file_format: None,
             location: None,
             query,
+            without_rowid,
         })
     }
 
